# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django import template
from django.utils.safestring import mark_safe
from classytags.arguments import Argument
from classytags.core import Options
from cms.templatetags.cms_tags import RenderPlaceholder


register = template.Library()


class GetPlaceholderContent(RenderPlaceholder):
    """
    With this tag, you can retrieve a placeholder's content into a variable

    Exemple :
        {% get_placeholder_content news.newsbox_body as body %}
            {% if body %}
                {{ body|safe }}
                some extra html
            {% else %}
                fall back
            {% endif %}
        {% endget_placeholder_content %}
    """
    name = 'get_placeholder_content'
    options = Options(
        Argument('placeholder', resolve=True),
        Argument('width', default=None, required=False),
        'language',
        Argument('language', default=None, required=False),
        'as',
        Argument('varname', resolve=False),
        blocks=[
            ('endget_placeholder_content', 'nodelist'),
        ]
    )

    def render_tag(self, context, placeholder, width, varname, language=None, nodelist=None):
        placeholder_output = None
        if placeholder:
            placeholder_output = super(GetPlaceholderContent, self).render_tag(
                context, placeholder, width, language)

        context.push()
        context[varname] = mark_safe(placeholder_output)
        output = nodelist.render(context)
        context.pop()
        return output


register.tag(GetPlaceholderContent)
